==> react-bootstrap-csv-export-1.0.0.tgz: package/lib/esm/ExportToCsvForm.js <==
import { __assign, __awaiter, __generator, __read } from "tslib";
import React, { useCallback, useState } from 'react';
import Alert from 'react-bootstrap/Alert';
import Button from 'react-bootstrap/Button';
import Col from 'react-bootstrap/Col';
import ProgressBar from 'react-bootstrap/ProgressBar';
import Row from 'react-bootstrap/Row';
import DefaultUserOptions from './DefaultUserOptions';
import generateCsv from './generateCsv';
import UserOptionsFormPart from './UserOptionsFormPart';
function ExportToCsvForm(_a) {
    var _this = this;
    var _b = _a.idPrefix, idPrefix = _b === void 0 ? 'csvExport' : _b, fileName = _a.fileName, fields = _a.fields, fetchPage = _a.fetchPage;
    var _c = __read(useState(DefaultUserOptions), 2), userOptions = _c[0], setUserOptions = _c[1];
    var _d = __read(useState(false), 2), retry = _d[0], setRetry = _d[1];
    var _e = __read(useState(null), 2), error = _e[0], setError = _e[1];
    var _f = __read(useState(false), 2), inProgress = _f[0], setInProgress = _f[1];
    var _g = __read(useState(0), 2), progress = _g[0], setProgress = _g[1];
    var _h = __read(useState(100), 2), progressMax = _h[0], setProgressMax = _h[1];
    var doGenerate = useCallback(function () { return void (function () { return __awaiter(_this, void 0, void 0, function () {
        var err_1;
        return __generator(this, function (_a) {
            switch (_a.label) {
                case 0:
                    setError(null);
                    setInProgress(true);
                    setProgress(0);
                    _a.label = 1;
                case 1:
                    _a.trys.push([1, 3, 4, 5]);
                    return [4 /*yield*/, generateCsv(__assign(__assign({}, userOptions), { fileName: fileName, fields: fields, fetchPage: fetchPage }), function (progress, progressMax) {
                            setProgress(progress);
                            setProgressMax(progressMax);
                        })];
                case 2:
                    _a.sent();
                    return [3 /*break*/, 5];
                case 3:
                    err_1 = _a.sent();
                    console.warn('Unable to export to CSV: ');
                    console.warn(err_1);
                    setError(err_1);
                    return [3 /*break*/, 5];
                case 4:
                    setInProgress(false);
                    setRetry(true);
                    return [7 /*endfinally*/];
                case 5: return [2 /*return*/];
            }
        });
    }); })(); }, [fetchPage, fields, fileName, setProgress, setProgressMax, userOptions]);
    return React.createElement(React.Fragment, null,
        React.createElement(Row, null,
            React.createElement(Col, null,
                React.createElement(UserOptionsFormPart, { disabled: inProgress, idPrefix: idPrefix + 'Options', onChange: setUserOptions, value: userOptions }))),
        error && React.createElement(Row, null,
            React.createElement(Col, null,
                React.createElement(Alert, { variant: "danger" },
                    'Error occured on CSV export: ',
                    error.message || JSON.stringify(error)))),
        React.createElement(Row, null,
            React.createElement(Col, null,
                React.createElement("div", { style: { marginBottom: 12 } },
                    React.createElement(ProgressBar, { animated: inProgress, max: progressMax, now: progress })))),
        React.createElement(Row, null,
            React.createElement(Col, null,
                React.createElement(Button, { disabled: inProgress, onClick: doGenerate }, retry ? 'Retry export to CSV' : 'Export to CSV'))));
}
export default React.memo(ExportToCsvForm);

==> react-bootstrap-csv-export-1.3.0.tgz: package/lib/esm/ExportToCsvForm.js <==
import { __assign, __awaiter, __generator, __read } from "tslib";
import Button from '@vlsergey/react-bootstrap-button-with-spinner';
import React, { useCallback, useState } from 'react';
import Alert from 'react-bootstrap/Alert';
import Col from 'react-bootstrap/Col';
import ProgressBar from 'react-bootstrap/ProgressBar';
import Row from 'react-bootstrap/Row';
import DefaultUserOptions from './DefaultUserOptions';
import generateCsv from './generateCsv';
import UserOptionsFormPart from './UserOptionsFormPart';
function ExportToCsvForm(_a) {
    var _this = this;
    var _b = _a.idPrefix, idPrefix = _b === void 0 ? 'csvExport' : _b, fileName = _a.fileName, fields = _a.fields, fetchPage = _a.fetchPage;
    var _c = __read(useState(DefaultUserOptions), 2), userOptions = _c[0], setUserOptions = _c[1];
    var _d = __read(useState(false), 2), retry = _d[0], setRetry = _d[1];
    var _e = __read(useState(null), 2), error = _e[0], setError = _e[1];
    var _f = __read(useState(false), 2), inProgress = _f[0], setInProgress = _f[1];
    var _g = __read(useState(0), 2), progress = _g[0], setProgress = _g[1];
    var _h = __read(useState(100), 2), progressMax = _h[0], setProgressMax = _h[1];
    var doGenerate = useCallback(function () { return __awaiter(_this, void 0, void 0, function () {
        var err_1;
        return __generator(this, function (_a) {
            switch (_a.label) {
                case 0:
                    setError(null);
                    setInProgress(true);
                    setProgress(0);
                    _a.label = 1;
                case 1:
                    _a.trys.push([1, 3, 4, 5]);
                    return [4 /*yield*/, generateCsv(__assign(__assign({}, userOptions), { fileName: fileName, fields: fields, fetchPage: fetchPage }), function (progress, progressMax) {
                            setProgress(progress);
                            setProgressMax(progressMax);
                        })];
                case 2:
                    _a.sent();
                    return [3 /*break*/, 5];
                case 3:
                    err_1 = _a.sent();
                    console.warn('Unable to export to CSV: ');
                    console.warn(err_1);
                    setError(err_1);
                    return [3 /*break*/, 5];
                case 4:
                    setInProgress(false);
                    setRetry(true);
                    return [7 /*endfinally*/];
                case 5: return [2 /*return*/];
            }
        });
    }); }, [fetchPage, fields, fileName, setProgress, setProgressMax, userOptions]);
    return React.createElement(React.Fragment, null,
        React.createElement(Row, null,
            React.createElement(Col, null,
                React.createElement(UserOptionsFormPart, { disabled: inProgress, idPrefix: idPrefix + 'Options', onChange: setUserOptions, value: userOptions }))),
        error && React.createElement(Row, null,
            React.createElement(Col, null,
                React.createElement(Alert, { variant: "danger" },
                    'Error occured on CSV export: ',
                    error.message || JSON.stringify(error)))),
        React.createElement(Row, null,
            React.createElement(Col, null,
                React.createElement("div", { style: { marginBottom: 12 } },
                    React.createElement(ProgressBar, { animated: inProgress, max: progressMax, now: progress })))),
        React.createElement(Row, null,
            React.createElement(Col, null,
                React.createElement(Button, { disabled: inProgress, onClick: doGenerate }, retry ? 'Retry export to CSV' : 'Export to CSV'))));
}
export default React.memo(ExportToCsvForm);
